@@ -29,7 +29,7 @@ from googletrans import Translator
 
 
 TOOL = 'subtrs'
-VERSION = 1.0
+VERSION = 1.1
 
 
 class Subtitles:
@@ -167,7 +167,3 @@ def main():
     check_usage(args)
     subs = Subtitles(args, flags)
     subs.write_new_subs()
-
-
-if __name__ == "__main__":
-    main()
